@@ -1,6 +1,6 @@
 use std::fmt;
 use std::str::FromStr;
-#[cfg(feature = "legacy")]
+#[cfg(feature = "astroport")]
 use std::convert::TryInto;
 
 use cosmwasm_std::{Addr, Api, Coin, CosmosMsg, StdError, StdResult};
@@ -419,7 +419,11 @@ impl AssetList {
     }
 }
 
-#[cfg(feature = "legacy")]
+//--------------------------------------------------------------------------------------------------
+// Optional Feature: Astroport Legacy Support
+//--------------------------------------------------------------------------------------------------
+
+#[cfg(feature = "astroport")]
 impl AssetList {
     /// Create an `AssetList` instance from an array of Astroport assets
     /// 
@@ -444,6 +448,10 @@ impl AssetList {
     }
 }
 
+//--------------------------------------------------------------------------------------------------
+// Tests
+//--------------------------------------------------------------------------------------------------
+
 #[cfg(test)]
 mod test_helpers {
     use super::super::asset::Asset;
@@ -670,8 +678,8 @@ mod tests {
     }
 }
 
-#[cfg(all(test, feature = "legacy"))]
-mod tests_legacy {
+#[cfg(all(test, feature = "astroport"))]
+mod tests_astroport {
     use super::test_helpers::mock_list;
     use super::*;
     use cosmwasm_std::Uint128;
